@@ -26,16 +26,11 @@
 
 namespace Minuet
 {
-IExerciseController::IExerciseController(QObject *parent)
-    : QObject(parent)
+IExerciseController::IExerciseController(QObject *parent) : QObject(parent)
 {
     qmlRegisterInterface<IExerciseController>("IExerciseController");
 }
 
-IExerciseController::~IExerciseController()
-{
-}
-
 void IExerciseController::setCurrentExercise(QVariantMap currentExercise)
 {
     if (m_currentExercise != currentExercise) {
